<?php

global $kippis_is_smartphone;
global $kippis_options;

add_action('after_setup_theme','kippis_setup');  // Runs before the init hook.

if (!function_exists('kippis_setup')) {
function kippis_setup()
{
  global $kippis_is_smartphone;
  global $kippis_options;
  require(dirname(__FILE__) . '/inc/class_mobile_detect.php');
  $pMobileDetect = new KMobileDetect();
  $kippis_is_smartphone = $pMobileDetect->isMobile();
  $kippis_options = kippis_get_options();
  if ($kippis_is_smartphone) add_filter('stylesheet_uri','kippis_stylesheet_uri');
  require(dirname(__FILE__) . '/inc/define.php');
  load_theme_textdomain('kippis',get_template_directory() . '/languages');
  $locale = get_locale();
  $locale_file = get_template_directory() . "/languages/$locale.php";
  if (is_readable($locale_file)) require_once($locale_file);
  add_editor_style();
  register_nav_menu('primary',__('Primary Menu','kippis'));
  add_theme_support('automatic-feed-links');
  add_theme_support('post-formats',array('gallery'/*,'aside','link','status','quote','image'*/));
  add_theme_support('post-thumbnails');
  set_post_thumbnail_size(KIPPIS_THUMBNAIL_WIDTH,KIPPIS_THUMBNAIL_HEIGHT,true);
  add_image_size('pic-large' ,KIPPIS_IMAGE_LARGE_WIDTH ,KIPPIS_IMAGE_LARGE_HEIGHT );
  add_image_size('pic-medium',KIPPIS_IMAGE_MEDIUM_WIDTH,KIPPIS_IMAGE_MEDIUM_HEIGHT);
  add_image_size('pic-small' ,KIPPIS_IMAGE_SMALL_WIDTH ,KIPPIS_IMAGE_SMALL_HEIGHT );
  add_image_size('pic-icon'  ,KIPPIS_IMAGE_ICON_WIDTH  ,KIPPIS_IMAGE_ICON_HEIGHT  );  // Mobile thumbnails.
  add_theme_support('custom-header',array('random-default' => true));
  if (is_admin()) require_once(get_template_directory() . '/options/kippis_admin.php');
}}

require(dirname(__FILE__) . '/inc/option_styles.php'     );
require(dirname(__FILE__) . '/inc/widget_post.php'       );

if (!function_exists('kippis_get_options')) {
function kippis_get_options()
{
  include get_template_directory() . '/options/init_fields.php';
  $kippis_options = array();
  foreach ($options as $option) {
    if (($option['type'] == 'open') || ($option['type'] == 'close') || ($option['type'] == 'displayonly')) continue;
    $optval = get_option($option['id']);
    if ($optval === false) $kippis_options[$option['id']] = $option['std'];
    else                   $kippis_options[$option['id']] = $optval;
  }
  return $kippis_options;
}}

if (!function_exists('kippis_enable_sidebars')) {
function kippis_enable_sidebars()
{
  global $kippis_options;
  global $kippis_sidebar_enable_left;
  global $kippis_sidebar_enable_right;
  $kippis_sidebar_enable_left  = (($kippis_options['kippis_sidebar_left_enable' ] == 'on') & ($kippis_options['kippis_sidebar_left_width' ] > 0));
  $kippis_sidebar_enable_right = (($kippis_options['kippis_sidebar_right_enable'] == 'on') & ($kippis_options['kippis_sidebar_right_width'] > 0));
  if ($kippis_sidebar_enable_left || $kippis_sidebar_enable_right) {
    $bSingular   = is_singular();
    $post_format = get_post_format();
    $post_type   = get_post_type();
    $bGallery    = ($post_format == 'gallery') || ($post_type == 'attachment');
    $bPage       = get_post_type() == 'page';
    $bPost       = (!$bPage) && ( $bSingular);
    $bPosts      = (!$bPage) && (!$bSingular);
    if ($kippis_sidebar_enable_left) {
      if      ($bGallery) $kippis_sidebar_enable_left  = $kippis_options['kippis_sidebar_left_enable_gallery' ] == 'on';
      else if ($bPage   ) $kippis_sidebar_enable_left  = $kippis_options['kippis_sidebar_left_enable_page'    ] == 'on';
      else if ($bPost   ) $kippis_sidebar_enable_left  = $kippis_options['kippis_sidebar_left_enable_post'    ] == 'on';
      else if ($bPosts  ) $kippis_sidebar_enable_left  = $kippis_options['kippis_sidebar_left_enable_posts'   ] == 'on';
    }
    if ($kippis_sidebar_enable_right) {
      if      ($bGallery) $kippis_sidebar_enable_right = $kippis_options['kippis_sidebar_right_enable_gallery'] == 'on';
      else if ($bPage   ) $kippis_sidebar_enable_right = $kippis_options['kippis_sidebar_right_enable_page'   ] == 'on';
      else if ($bPost   ) $kippis_sidebar_enable_right = $kippis_options['kippis_sidebar_right_enable_post'   ] == 'on';
      else if ($bPosts  ) $kippis_sidebar_enable_right = $kippis_options['kippis_sidebar_right_enable_posts'  ] == 'on';
    }
  }
}}

if (!function_exists('kippis_stylesheet_uri')) {
function kippis_stylesheet_uri()
{
  $stylesheet_uri = get_template_directory_uri() . "/style_mobile.css";
  return $stylesheet_uri;
}}

if (!function_exists('kippis_admin_header_image')) {
function kippis_admin_header_image()
{
  ?>
  <div id="headimg">
    <?php
    if ('blank' == get_theme_mod('header_textcolor',HEADER_TEXTCOLOR) || '' == get_theme_mod('header_textcolor',HEADER_TEXTCOLOR)) {
      $style = ' style="display:none;"';
    }
    else $style = ' style="color:#' . get_theme_mod('header_textcolor',HEADER_TEXTCOLOR) . ';"';
    ?>
    <h1><a id="name"<?php echo $style; ?> onclick="return false;" href="<?php echo esc_url(home_url('/') ); ?>"><?php bloginfo('name'); ?></a></h1>
    <div id="desc"<?php echo $style; ?>><?php bloginfo('description'); ?></div>
    <?php $header_image = get_header_image();
    if (!empty($header_image)) : ?>
      <img src="<?php echo esc_url($header_image); ?>" alt="" />
    <?php endif; ?>
  </div>
  <?php
}}

//-----------------------------------------------------------------------------------------------------------------------------
//
//  Excerpt Begin
//
if (!function_exists('kippis_excerpt_length')) {
function kippis_excerpt_length($length)
{
  return KIPPIS_EXCERPT_LENGTH;
}}

if (!function_exists('kippis_continue_reading_link')) {
function kippis_continue_reading_link()
{
  return ' <span class="continue-reading"><a href="'. esc_url(get_permalink()) . '">' . __('Continue reading <span class="meta-nav">&rarr;</span>','kippis') . '</a></span>';
}}

if (!function_exists('kippis_auto_excerpt_more')) {
function kippis_auto_excerpt_more($more)
{
  return ' &hellip;' . kippis_continue_reading_link();
}}

if (!function_exists('kippis_custom_excerpt_more')) {
function kippis_custom_excerpt_more($output)
{
  if (has_excerpt() && !is_attachment()) {
    $output .= kippis_continue_reading_link();
  }
  return $output;
}}

add_filter('excerpt_length' ,'kippis_excerpt_length'     );
add_filter('excerpt_more'   ,'kippis_auto_excerpt_more'  );
add_filter('get_the_excerpt','kippis_custom_excerpt_more');
//
//  Excerpt End
//
//-----------------------------------------------------------------------------------------------------------------------------

if (!function_exists('kippis_page_menu_args')) {
function kippis_page_menu_args($args)
{
  $args['show_home'] = true;
  return $args;
}}
add_filter('wp_page_menu_args','kippis_page_menu_args');

if (!function_exists('kippis_content_nav')) {
function kippis_content_nav( $nav_id )
{
  global $wp_query;
  if ($wp_query->max_num_pages > 1) {
    ?>
    <nav id="<?php echo $nav_id; ?>">
      <div class="nav-previous"><?php next_posts_link( __('<span class="meta-nav">&larr;</span> Older posts','kippis')); ?></div>
      <div class="nav-next"><?php previous_posts_link( __('Newer posts <span class="meta-nav">&rarr;</span>','kippis')); ?></div>
    </nav><!-- #nav-above -->
    <?php
  }
}}

if (!function_exists('kippis_url_grabber')) {
function kippis_url_grabber()
{
  if (!preg_match('/<a\s[^>]*?href=[\'"](.+?)[\'"]/is',get_the_content(),$matches)) return false;
  return esc_url_raw($matches[1]);
}}

//-----------------------------------------------------------------------------------------------------------------------------
//
//  Sidebars Begin
//
if (!function_exists('kippis_register_sidebar')) {
function kippis_register_sidebar($id,$name,$desc = '')
{
  register_sidebar(array('id'            => $id                                      // Sidebar id - Must be all in lowercase, with no spaces.
                        ,'name'          => $name                                    // Sidebar name.
                        ,'description'   => $desc                                    // Text description of what/where the sidebar is. Shown(?) on widget management screen.
                        ,'before_widget' => '<aside id="%1$s" class="widget %2$s">'  // HTML to place before every widget.  |  %1$s = id  %2$s = class
                        ,'after_widget'  => '</aside>'                               // HTML to place after every widget.
                        ,'before_title'  => '<h3 class="widget-title">'              // HTML to place before every title.
                        ,'after_title'   => '</h3>'                                  // HTML to place after every title.
                        ));

}}

if (!function_exists('kippis_widgets_init')) {
function kippis_widgets_init()
{
  kippis_register_sidebar('sidebar-left'        ,__('Left Sidebar'     ,'kippis'));
  kippis_register_sidebar('sidebar-right'       ,__('Right Sidebar'    ,'kippis'));
  kippis_register_sidebar('sidebar-footer-one'  ,__('Footer Area One'  ,'kippis'));
  kippis_register_sidebar('sidebar-footer-two'  ,__('Footer Area Two'  ,'kippis'));
  kippis_register_sidebar('sidebar-footer-three',__('Footer Area Three','kippis'));
  kippis_register_sidebar('sidebar-footer-four' ,__('Footer Area Four' ,'kippis'));
  register_widget('kippis_widget_post');
}}
add_action('widgets_init','kippis_widgets_init');
//
//  Sidebars End
//
//-----------------------------------------------------------------------------------------------------------------------------

if (!function_exists('kippis_strip_img_width')) {
function kippis_strip_img_width($html)
{
  return preg_replace('/\<(.*?)(width="(.*?)")(.*?)(height="(.*?)")(.*?)\>/i','<$1$4$7>',$html);
}}

if (!function_exists('kippis_comment')) {
function kippis_comment($comment,$args,$depth)
{
  $GLOBALS['comment'] = $comment;
  switch ($comment->comment_type) :
    case 'pingback':
    case 'trackback':
  ?>
  <li class="post pingback">
    <p><?php _e('Pingback:','kippis'); ?> <?php comment_author_link(); ?> <?php edit_comment_link(__('Edit','kippis'),'<span class="edit-link">','</span>'); ?></p>
  <?php
      break;
    default:
  ?>
  <li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
    <div id="comment-<?php comment_ID(); ?>" class="article comment">
      <footer class="comment-meta">
        <div class="comment-author vcard">
          <?php
            $avatar_size = 68;
            if ('0' != $comment->comment_parent) $avatar_size = 39;
            echo get_avatar($comment,$avatar_size);
            /* translators: 1: comment author, 2: date and time */
            printf( __( '%1$s on %2$s <span class="says">said:</span>', 'kippis' ),
              sprintf('<span class="fn">%s</span>',get_comment_author_link()),
              sprintf('<a href="%1$s"><time pubdate datetime="%2$s">%3$s</time></a>'
                ,esc_url(get_comment_link($comment->comment_ID))
                ,get_comment_time( 'c' )
                ,sprintf(__('%1$s at %2$s','kippis'),get_comment_date(),get_comment_time())
              )
            );
          ?>
          <?php edit_comment_link( __( 'Edit', 'kippis' ), '<span class="edit-link">', '</span>' ); ?>
        </div><!-- .comment-author .vcard -->
        <?php if ( $comment->comment_approved == '0' ) : ?>
          <em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'kippis' ); ?></em>
          <br />
        <?php endif; ?>
      </footer>
      <div class="comment-content"><?php comment_text(); ?></div>
      <div class="reply">
        <?php comment_reply_link(array_merge($args,array('reply_text' => __('Reply <span>&darr;</span>','kippis'),'depth' => $depth,'max_depth' => $args['max_depth']))); ?>
      </div><!-- .reply -->
    </div><!-- #comment-## -->
  <?php
      break;
  endswitch;
}}

if (!function_exists('kippis_posted_on')) {
function kippis_posted_on()
{
  printf(__('<span class="sep">Posted on </span>'
          . '<a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s" pubdate>%4$s</time></a>'
          . '<span class="by-author"> <span class="sep"> by </span> <span class="author vcard">'
          . '<a class="url fn n" href="%5$s" title="%6$s" rel="author">%7$s</a>'
          . '</span></span>'
          ,'kippis'),
    esc_url (get_permalink()),
    esc_attr(get_the_time()),
    esc_attr(get_the_date('c')),
    esc_html(get_the_date()),
    esc_url (get_author_posts_url(get_the_author_meta('ID'))),
    sprintf (esc_attr__('View all posts by %s','kippis'),get_the_author()),
    esc_html(get_the_author())
  );
}}

if (!function_exists('kippis_body_classes')) {
function kippis_body_classes($classes)
{
  if (!is_multi_author()) {
    $classes[] = 'single-author';
  }
  if (is_singular() && !is_home() && !is_page_template('showcase.php') && !is_page_template('sidebar-page.php')) {
    $classes[] = 'singular';
  }
  return $classes;
}}
add_filter('body_class','kippis_body_classes');

if (!function_exists('kippis_credits')) {
function kippis_credits()
{
  $data = get_theme_data(get_template_directory() . '/style.css');
  echo 'WordPress theme: ' . '<a href="' . $data['URI'] . '" title="' . $data['Description'] . '">'
     . $data['Name'] . ' ' . $data['Version']
     . '</a>';
}}

if (!function_exists('kippis_is_smartphone')) {
function kippis_is_smartphone()
{
  global $kippis_is_smartphone;
  return $kippis_is_smartphone;
}}

